import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.image.BufferedImage;
import java.io.File;
import javax.imageio.ImageIO;
import javax.swing.ButtonGroup;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import java.awt.BorderLayout;
import javax.swing.JPanel;
import java.awt.Color;
import javax.swing.JRadioButton;
import javax.swing.JTextField;
import javax.swing.SwingUtilities;

/**
 * Another GUI example.  You'll need to also
 * download the pineapple-pizza.jpg file and copy it into your project (not in the source
 * folder, but in the main project folder.
 */
public class PineapplePizzaExample extends JFrame {

    private static final long serialVersionUID = 1L;
    private JRadioButton rdbtnYes;
    private JRadioButton rdbtnNo;
    private JTextField rationale;
    private JLabel buttonEventLabel;
    private JPanel left;
    private JPanel right;

    /**
     * Launch the GUI application. Note that the new class that extends Runnable is defined in-line. This is another way to
     * define and instantiate an object of type Runnable.
     */
    public static void main(String[] args) {
        SwingUtilities.invokeLater(new Runnable() {
            public void run() {
                try {
                    // Create a new Window
                    PineapplePizzaExample window = new PineapplePizzaExample();

                    // Resize to fit content
                    window.pack();

                    // Display the Window
                    window.setVisible(true);
                } catch (Exception e) {
                    e.printStackTrace();
                }
            }
        });
    }

    /**
     * Create the application. Note that this is similar to the example with createAndShowGUI(), except this example calls
     * the initialize() method from the constructor instead!
     */
    public PineapplePizzaExample() {
        initialize();
    }

    /**
     * Initialize the contents of the frame. This is similar to the addComponentsToPane() method from our other example.
     */
    private void initialize() {
        // Initial Size (minW minH maxW maxH)
        setBounds(100, 100, 450, 300);

        // Set what happens when you click the close button
        setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

        // Give it a layout: border = NORTH, SOUTH, EAST, WEST, and CENTER
        getContentPane().setLayout(new BorderLayout());

        // Pineapple on Pizza?
        JPanel panel4 = new JPanel();
        panel4.add(new JLabel("Do you like pineapple on your pizza?"));

        rdbtnYes = new JRadioButton("Yes");
        rdbtnNo = new JRadioButton("No");
        ButtonGroup pineapple = new ButtonGroup();
        pineapple.add(rdbtnYes);
        pineapple.add(rdbtnNo);
        panel4.add(rdbtnYes);
        panel4.add(rdbtnNo);

        // Add panel4 to the window (center)
        getContentPane().add(panel4, BorderLayout.CENTER);

        // Reasoning for Pineapples?
        JPanel panel2 = new JPanel();
        panel2.add(new JLabel("Reasoning: "));
        rationale = new JTextField(15);
        panel2.add(rationale);

        // Submit button for the reasoning
        JButton btn = new JButton("Submit");
        btn.setActionCommand("submit"); // command is submit
        btn.addActionListener(new ButtonListener()); // listener for the button click
        panel2.add(btn);
        
        // Add a label that we can control with the button click
        buttonEventLabel = new JLabel();
        panel2.add(buttonEventLabel);
        
        // Add panel2 to the window (bottom)
        getContentPane().add(panel2, BorderLayout.SOUTH);

        // Read in an image for the top of the window
        JPanel panel = new JPanel();
        panel.setBackground(Color.WHITE);
        try { // why this? Checked Exception (what if file doesn't exist!)
              // Note that the filenames without a path are in the root of our project (drag/drop the file)
            BufferedImage myPicture = ImageIO.read(new File("pineapple-pizza.jpg"));
            JLabel picLabel = new JLabel(new ImageIcon(myPicture));
            panel.add(picLabel);
        } catch (Exception e) {
            e.printStackTrace();
        }
        // Add it to the top!
        getContentPane().add(panel, BorderLayout.NORTH);
        // Add some panels to the left and right to test out changing colors
        left = new JPanel();
        getContentPane().add(left, BorderLayout.WEST);
        right = new JPanel();
        getContentPane().add(right, BorderLayout.EAST);

        // add listeners to the Pineapple radio buttons
        rdbtnYes.setActionCommand("radio"); // command is radio, see below
        rdbtnNo.setActionCommand("radio");
        rdbtnYes.addActionListener(new ButtonListener());
        rdbtnNo.addActionListener(new ButtonListener());
    }

    private class ButtonListener implements ActionListener {

        @Override
        public void actionPerformed(ActionEvent e) {
            // When the action that's performed is submit, then change text
            if (e.getActionCommand().equals("submit")) {
                if (rdbtnYes.isSelected()) {
                    buttonEventLabel.setText("Eww!");
                } else if (rdbtnNo.isSelected()) {
                    buttonEventLabel.setText("Why!");
                }
            // When the action that's performed is radio, then change colors
            } else if (e.getActionCommand().equals("radio")) {
                if (rdbtnYes.isSelected()) {
                    left.setBackground(Color.RED);
                    right.setBackground(null);
                } else if (rdbtnNo.isSelected()) {
                    left.setBackground(null);
                    right.setBackground(Color.GREEN);
                }
            }
        }

    }

}
